@@ -2,6 +2,7 @@ import os
 import zipfile
 
 from .cmake_init import main
+from .template import compile_template
 
 def pypi_main():
     zip = zipfile.ZipFile(
@@ -11,6 +12,6 @@ def pypi_main():
     try:
         # open a dummy fd to keep the zip from being closed
         with zip.open("templates/common/.gitignore") as dummy_fp:
-            main(zip)
+            main(zip, compile_template)
     except KeyboardInterrupt:
         pass
